@@ -82,6 +82,12 @@ class IFourdigitsPortletTwitter(IPortletDataProvider):
         description=_(u"The tweets of this user will be shown"),
         required=False,)
 
+    includerts = schema.Bool(
+        title=_(u"Include retweets"),
+        description=_(u"Include retweets of the user's account?"),
+        required=False,
+        default=True,)
+
     search = schema.Text(
         title=_(u"Search"),
         description=_(u"The tweets containing this text will be shown\
@@ -135,10 +141,11 @@ class Assignment(base.Assignment):
     """
 
     implements(IFourdigitsPortletTwitter)
+    includerts = True
 
     def __init__(self, name=u"", username=u"", search=u"", filtertext="",
                  userdisplay=5, searchdisplay=5, searchlimit=40,
-                 language="", userpictures=False):
+                 language="", userpictures=False, includerts=True):
         self.name = name
         self.username = username
         self.search = search
@@ -148,6 +155,7 @@ class Assignment(base.Assignment):
         self.searchlimit = searchlimit
         self.language = language
         self.userpictures = userpictures
+        self.includerts = includerts
 
     @property
     def title(self):
@@ -184,10 +192,12 @@ class Renderer(base.Renderer):
         """Twitter messages"""
         return self.getTweets()
 
-    def getTweetsOfUser(self, username, userpictures):
+    def getTweetsOfUser(self, username, userpictures, includerts):
         """Return the tweets of a certain user"""
         try:
-            tweets = self.twapi.GetUserTimeline(username)
+
+            tweets = self.twapi.GetUserTimeline(username,
+                                                includerts=includerts)
         except URLError:
             tweets = []
         return tweets
@@ -216,13 +226,16 @@ class Renderer(base.Renderer):
         filtertext = self.data.filtertext
         languages = self.data.language
         userpictures = self.data.userpictures
+        includerts = self.data.includerts
 
         results = []
         tweets = []
 
         # get tweets of username
         if username:
-            tweets = self.getTweetsOfUser(username, userpictures)
+            tweets = self.getTweetsOfUser(username,
+                                          userpictures,
+                                          includerts)
         tweets = tweets[:userdisplay]
 
         searchresults = []
