@@ -1508,7 +1508,8 @@ class Api(object):
                       since_id=None,
                       max_id=None,
                       count=None,
-                      page=None):
+                      page=None,
+                      includerts=None):
     '''Fetch the sequence of public Status messages for a single user.
 
     The twitter.Api instance must be authenticated if the user is private.
@@ -1542,9 +1543,8 @@ class Api(object):
       A sequence of Status instances, one for each message up to count
     '''
     parameters = {}
-
     if id:
-      url = 'http://twitter.com/statuses/user_timeline/%s.json' % id
+      url = 'http://api.twitter.com/1/statuses/user_timeline.json?screen_name=%s' % id
     elif user_id:
       url = 'http://twitter.com/statuses/user_timeline.json?user_id=%d' % user_id
     elif screen_name:
@@ -1553,7 +1553,10 @@ class Api(object):
     elif not self._username:
       raise TwitterError("User must be specified if API is not authenticated.")
     else:
-      url = 'http://twitter.com/statuses/user_timeline.json'
+      url = 'http://api.twitter.com/1/statuses/user_timeline.json'
+
+    if includerts:
+        url = "%s&include_rts=true" % url
 
     if since_id:
       try:
